Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.bitcoind`` role allows you to manage and configure bitcoind_.
bitcoind can be used to run a `full node`_ in the distributed cryptocurrency network Bitcoin_.
A full node is a program that fully validates transactions and blocks and
therefore enforces all of the rules of Bitcoin.

Refer to `Running A Full Node`_ for details.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.5``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops-contrib.bitcoind

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
